@@ -136,7 +136,7 @@ my %channelStruct = (
 %Image::ExifTool::GM::marl = (
     PROCESS_PROC => \&Process_marl,
     GROUPS => { 2 => 'Other' },
-    VARS => { NO_ID => 1, NO_LOOKUP => 1 },
+    VARS => { ID_FMT => 'none', NO_LOOKUP => 1 },
     NOTES => q{
         Tags extracted from the 'ctbx' 'marl' (Marlin) box of timed PDR metadata
         from GM cars.  Use the -ee (L<API ExtractEmbedded|../ExifTool.html#ExtractEmbedded>) option to extract this
@@ -437,7 +437,7 @@ sub Process_marl($$$)
 {
     my ($et, $dirInfo, $tagTablePtr) = @_;
     my $dataPt = $$dirInfo{DataPt};
-    my $dataPos = $$dirInfo{DataPos} + $$dirInfo{Base};
+    my $dataPos = ($$dirInfo{DataPos} || 0) + ($$dirInfo{Base} || 0);
     my $dataLen = length $$dataPt;
     my $vals = $$et{GMVals}; # running values for each channel (0=TimeStamp)
     my $chan = $$et{GMChan}; # running channel number
