@@ -79,79 +79,6 @@ my %sTimecode = (
     timeValue   => { },
     value       => { Writable => 'integer', Notes => 'only in XMP 2008 spec; an error?' },
 );
-my %sPose = (
-    STRUCT_NAME => 'Pose',
-    NAMESPACE => { Pose => 'http://ns.google.com/photos/dd/1.0/pose/' },
-    PositionX => { Writable => 'real', Groups => { 2 => 'Location' } },
-    PositionY => { Writable => 'real', Groups => { 2 => 'Location' } },
-    PositionZ => { Writable => 'real', Groups => { 2 => 'Location' } },
-    RotationX => { Writable => 'real', Groups => { 2 => 'Location' } },
-    RotationY => { Writable => 'real', Groups => { 2 => 'Location' } },
-    RotationZ => { Writable => 'real', Groups => { 2 => 'Location' } },
-    RotationW => { Writable => 'real', Groups => { 2 => 'Location' } },
-    Timestamp => {
-        Writable => 'integer',
-        Shift => 'Time',
-        Groups => { 2 => 'Time' },
-        ValueConv => 'ConvertUnixTime($val / 1000, 1, 3)',
-        ValueConvInv => 'int(GetUnixTime($val, 1) * 1000)',
-        PrintConv => '$self->ConvertDateTime($val)',
-        PrintConvInv => '$self->InverseDateTime($val,undef,1)',
-    },
-);
-my %sEarthPose = (
-    STRUCT_NAME => 'EarthPose',
-    NAMESPACE => { EarthPose => 'http://ns.google.com/photos/dd/1.0/earthpose/' },
-    Latitude  => {
-        Writable => 'real',
-        Groups => { 2 => 'Location' }, 
-        ValueConv    => 'Image::ExifTool::GPS::ToDegrees($val, 1)',
-        ValueConvInv => '$val',
-        PrintConv    => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "N")',
-        PrintConvInv => 'Image::ExifTool::GPS::ToDegrees($val, 1, "lat")',
-    },
-    Longitude => {
-        Writable => 'real',
-        Groups => { 2 => 'Location' },
-        ValueConv    => 'Image::ExifTool::GPS::ToDegrees($val, 1)',
-        ValueConvInv => '$val',
-        PrintConv    => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "E")',
-        PrintConvInv => 'Image::ExifTool::GPS::ToDegrees($val, 1, "lon")',
-    },
-    Altitude  => {
-        Writable => 'real',
-        Groups => { 2 => 'Location' },
-        PrintConv => '"$val m"',
-        PrintConvInv => '$val=~s/\s*m$//;$val',
-    },
-    RotationX => { Writable => 'real', Groups => { 2 => 'Location' } },
-    RotationY => { Writable => 'real', Groups => { 2 => 'Location' } },
-    RotationZ => { Writable => 'real', Groups => { 2 => 'Location' } },
-    RotationW => { Writable => 'real', Groups => { 2 => 'Location' } },
-    Timestamp => {
-        Writable => 'integer',
-        Shift => 'Time',
-        Groups => { 2 => 'Time' },
-        ValueConv => 'ConvertUnixTime($val / 1000, 1, 3)',
-        ValueConvInv => 'int(GetUnixTime($val, 1) * 1000)',
-        PrintConv => '$self->ConvertDateTime($val)',
-        PrintConvInv => '$self->InverseDateTime($val,undef,1)',
-    },
-);
-my %sVendorInfo = (
-    STRUCT_NAME => 'VendorInfo',
-    NAMESPACE   => { VendorInfo => 'http://ns.google.com/photos/dd/1.0/vendorinfo/' },
-    Model => { },
-    Manufacturer => { },
-    Notes => { },
-);
-my %sAppInfo = (
-    STRUCT_NAME => 'AppInfo',
-    NAMESPACE   => { AppInfo => 'http://ns.google.com/photos/dd/1.0/appinfo/' },
-    Application => { },
-    Version => { },
-    ItemURI => { },
-);
 
 # camera-raw defaults
 %Image::ExifTool::XMP::crd = (
@@ -572,11 +499,12 @@ my %sImageRegion = ( # new in 1.5
     NAMESPACE   => 'Iptc4xmpExt',
     TABLE_DESC => 'XMP IPTC Extension',
     NOTES => q{
-        This table contains tags defined by the IPTC Extension schema version 1.7
-        and IPTC Video Metadata version 1.3. The actual namespace prefix is
-        "Iptc4xmpExt", but ExifTool shortens this for the family 1 group name. (See
-        L<http://www.iptc.org/standards/photo-metadata/iptc-standard/> and
-        L<https://iptc.org/standards/video-metadata-hub/>.)
+This table contains tags defined by the IPTC Extension schema version 1.7
+and IPTC Video Metadata version 1.3, plus the AI additions.  The actual
+namespace prefix is "Iptc4xmpExt", but ExifTool shortens this for the family
+1 group name. (See
+L<http://www.iptc.org/standards/photo-metadata/iptc-standard/> and
+L<https://iptc.org/standards/video-metadata-hub/>.)
     },
     AboutCvTerm => {
         Struct => \%sCVTermDetails,
@@ -842,6 +770,11 @@ my %sImageRegion = ( # new in 1.5
     ImageRegion => { Groups => { 2 => 'Image' }, List => 'Bag', Struct => \%sImageRegion },
     # new Extension 1.6 property
     EventId     => { Name => 'EventID', List => 'Bag' },
+    # new AI tags
+    AISystemUsed        => { },
+    AISystemVersionUsed => { },
+    AIPromptInformation => { },
+    AIPromptWriterName  => { },
 );
 
 #------------------------------------------------------------------------------
@@ -1760,414 +1693,6 @@ my %sACDSeeRegionStruct = (
     ConfidenceLevel => { Writable => 'integer' },
 );
 
-# Google audio namespace
-%Image::ExifTool::XMP::GAudio = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-GAudio', 2 => 'Audio' },
-    NAMESPACE => 'GAudio',
-    Data => {
-        Name => 'AudioData',
-        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
-        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
-    },
-    Mime => { Name => 'AudioMimeType' },
-);
-
-# Google image namespace
-%Image::ExifTool::XMP::GImage = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-GImage', 2 => 'Image' },
-    NAMESPACE => 'GImage',
-    Data => {
-        Name => 'ImageData',
-        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
-        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
-    },
-    Mime => { Name => 'ImageMimeType' },
-);
-
-# Google panorama namespace properties
-# (ref https://exiftool.org/forum/index.php/topic,4569.0.html)
-%Image::ExifTool::XMP::GPano = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-GPano', 2 => 'Image' },
-    NAMESPACE => 'GPano',
-    NOTES => q{
-        Panorama tags written by Google Photosphere. See
-        L<https://developers.google.com/panorama/metadata/> for the specification.
-    },
-    UsePanoramaViewer               => { Writable => 'boolean' },
-    CaptureSoftware                 => { },
-    StitchingSoftware               => { },
-    ProjectionType                  => { },
-    PoseHeadingDegrees              => { Writable => 'real' },
-    PosePitchDegrees                => { Writable => 'real' },
-    PoseRollDegrees                 => { Writable => 'real' },
-    InitialViewHeadingDegrees       => { Writable => 'real' },
-    InitialViewPitchDegrees         => { Writable => 'real' },
-    InitialViewRollDegrees          => { Writable => 'real' },
-    InitialHorizontalFOVDegrees     => { Writable => 'real' },
-    InitialVerticalFOVDegrees       => { Writable => 'real' },
-    FirstPhotoDate                  => { %dateTimeInfo, Groups => { 2 => 'Time' } },
-    LastPhotoDate                   => { %dateTimeInfo, Groups => { 2 => 'Time' } },
-    SourcePhotosCount               => { Writable => 'integer' },
-    ExposureLockUsed                => { Writable => 'boolean' },
-    CroppedAreaImageWidthPixels     => { Writable => 'real' },
-    CroppedAreaImageHeightPixels    => { Writable => 'real' },
-    FullPanoWidthPixels             => { Writable => 'real' },
-    FullPanoHeightPixels            => { Writable => 'real' },
-    CroppedAreaLeftPixels           => { Writable => 'real' },
-    CroppedAreaTopPixels            => { Writable => 'real' },
-    InitialCameraDolly              => { Writable => 'real' },
-    # (the following have been observed, but are not in the specification)
-    LargestValidInteriorRectLeft    => { Writable => 'real' },
-    LargestValidInteriorRectTop     => { Writable => 'real' },
-    LargestValidInteriorRectWidth   => { Writable => 'real' },
-    LargestValidInteriorRectHeight  => { Writable => 'real' },
-);
-
-# Google Spherical Images namespace (ref https://github.com/google/spatial-media/blob/master/docs/spherical-video-rfc.md)
-%Image::ExifTool::XMP::GSpherical = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-GSpherical', 2 => 'Image' },
-    WRITE_GROUP => 'GSpherical', # write in special location for video files
-    NAMESPACE => 'GSpherical',
-    AVOID => 1,
-    NOTES => q{
-        Not actually XMP.  These RDF/XML tags are used in Google spherical MP4
-        videos.  These tags are written into the video track of MOV/MP4 files, and
-        not at the top level like other XMP tags.  See
-        L<https://github.com/google/spatial-media/blob/master/docs/spherical-video-rfc.md>
-        for the specification.
-    },
-    # (avoid due to conflicts with XMP-GPano tags)
-    Spherical                   => { Writable => 'boolean' },
-    Stitched                    => { Writable => 'boolean' },
-    StitchingSoftware           => { },
-    ProjectionType              => { },
-    StereoMode                  => { },
-    SourceCount                 => { Writable => 'integer' },
-    InitialViewHeadingDegrees   => { Writable => 'real' },
-    InitialViewPitchDegrees     => { Writable => 'real' },
-    InitialViewRollDegrees      => { Writable => 'real' },
-    Timestamp                   => {
-        Name => 'TimeStamp',
-        Groups => { 2 => 'Time' },
-        Writable => 'integer',
-        Shift => 'Time',
-        ValueConv => 'ConvertUnixTime($val)', #(NC)
-        ValueConvInv => 'GetUnixTime($val)',
-        PrintConv => '$self->ConvertDateTime($val)',
-        PrintConvInv => '$self->InverseDateTime($val)',
-    },
-    FullPanoWidthPixels         => { Writable => 'integer' },
-    FullPanoHeightPixels        => { Writable => 'integer' },
-    CroppedAreaImageWidthPixels => { Writable => 'integer' },
-    CroppedAreaImageHeightPixels=> { Writable => 'integer' },
-    CroppedAreaLeftPixels       => { Writable => 'integer' },
-    CroppedAreaTopPixels        => { Writable => 'integer' },
-);
-
-# Google depthmap information (ref https://developers.google.com/depthmap-metadata/reference)
-%Image::ExifTool::XMP::GDepth = (
-    GROUPS      => { 0 => 'XMP', 1 => 'XMP-GDepth', 2 => 'Image' },
-    NAMESPACE   => 'GDepth',
-    AVOID       => 1, # (too many potential tag name conflicts)
-    NOTES       => q{
-        Google depthmap information. See
-        L<https://developers.google.com/depthmap-metadata/> for the specification.
-    },
-    WRITABLE    => 'string', # (default to string-type tags)
-    PRIORITY    => 0,
-    Format => {
-        PrintConv => {
-            RangeInverse => 'RangeInverse',
-            RangeLinear  => 'RangeLinear',
-        },
-    },
-    Near        => { Writable => 'real' },
-    Far         => { Writable => 'real' },
-    Mime        => { },
-    Data => {
-        Name => 'DepthImage',
-        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
-        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
-    },
-    Units       => { },
-    MeasureType => {
-        PrintConv => {
-            OpticalAxis => 'OpticalAxis',
-            OpticalRay  => 'OpticalRay',
-        },
-    },
-    ConfidenceMime  => { },
-    Confidence => {
-        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
-        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
-    },
-    Manufacturer=> { },
-    Model       => { },
-    Software    => { },
-    ImageWidth  => { Writable => 'real' },
-    ImageHeight => { Writable => 'real' },
-);
-
-# Google focus namespace
-%Image::ExifTool::XMP::GFocus = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-GFocus', 2 => 'Image' },
-    NAMESPACE => 'GFocus',
-    NOTES => 'Focus information found in Google depthmap images.',
-    BlurAtInfinity  => { Writable => 'real' },
-    FocalDistance   => { Writable => 'real' },
-    FocalPointX     => { Writable => 'real' },
-    FocalPointY     => { Writable => 'real' },
-);
-
-# Google camera namespace (ref PH)
-%Image::ExifTool::XMP::GCamera = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-GCamera', 2 => 'Camera' },
-    NAMESPACE => 'GCamera',
-    NOTES => 'Camera information found in Google panorama images.',
-    BurstID         => { },
-    BurstPrimary    => { },
-    PortraitNote    => { },
-    PortraitRequest => {
-        Notes => 'HDRPlus (HDRP) data', #NealKrawetz
-        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
-        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
-    },
-    PortraitVersion => { },
-    SpecialTypeID   => { List => 'Bag' },
-    PortraitNote    => { },
-    DisableAutoCreation => { List => 'Bag' },
-    DisableSuggestedAction => { List => 'Bag' }, #forum16147
-    hdrp_makernote => {
-        Name => 'HDRPMakerNote',
-        # decoded data starts with the following bytes, but nothing yet is known about its contents:
-        # 48 44 52 50 02 ef 64 35 6d 5e 70 1e 2c ea e3 4c [HDRP..d5m^p.,..L]
-        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
-        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
-    },
-    MicroVideo          => { Writable => 'integer' },
-    MicroVideoVersion   => { Writable => 'integer' },
-    MicroVideoOffset    => { Writable => 'integer' },
-    MicroVideoPresentationTimestampUs => { Writable => 'integer' },
-    shot_log_data => { #forum14108
-        Name => 'ShotLogData',
-        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
-        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
-    },
-    HdrPlusMakernote => {
-        ValueConv => 'Image::ExifTool::XMP::DecodeBase64($val)',
-        ValueConvInv => 'Image::ExifTool::XMP::EncodeBase64($val)',
-    },
-    MotionPhoto        => { Writable => 'integer' },
-    MotionPhotoVersion => { Writable => 'integer' },
-    MotionPhotoPresentationTimestampUs => { Writable => 'integer' },
-);
-
-# Google creations namespace (ref PH)
-%Image::ExifTool::XMP::GCreations = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-GCreations', 2 => 'Camera' },
-    NAMESPACE => 'GCreations',
-    NOTES => 'Google creations tags.',
-    CameraBurstID  => { },
-    Type => { Avoid => 1 },
-);
-
-# Google depth-map Device namespace (ref 13)
-%Image::ExifTool::XMP::Device = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-Device', 2 => 'Camera' },
-    NAMESPACE => { Device => 'http://ns.google.com/photos/dd/1.0/device/' },
-    NOTES => q{
-        Google depth-map Device tags.  See
-        L<https://developer.android.com/training/camera2/Dynamic-depth-v1.0.pdf> for
-        the specification.
-    },
-    Container => {
-        Struct => {
-            STRUCT_NAME => 'DeviceContainer',
-            NAMESPACE   => { Container => 'http://ns.google.com/photos/dd/1.0/container/' },
-            Directory => {
-                List => 'Seq',
-                Struct => {
-                    STRUCT_NAME => 'DeviceDirectory',
-                    NAMESPACE   => { Container => 'http://ns.google.com/photos/dd/1.0/container/' },
-                    Item => {
-                        Struct => {
-                            STRUCT_NAME => 'DeviceItem',
-                            NAMESPACE => { Item => 'http://ns.google.com/photos/dd/1.0/item/' },
-                            # use this as a key to process Google trailer
-                            Mime    => { RawConv => '$$self{ProcessGoogleTrailer} = $val' },
-                            Length  => { Writable => 'integer' },
-                            Padding => { Writable => 'integer' },
-                            DataURI => { },
-                        },
-                    },
-                },
-            }
-        },
-    },
-    Profiles => {
-        List => 'Seq',
-        FlatName => '',
-        Struct => {
-            STRUCT_NAME => 'DeviceProfiles',
-            NAMESPACE => { Device => 'http://ns.google.com/photos/dd/1.0/device/' },
-            Profile => {
-                Struct => {
-                    STRUCT_NAME => 'DeviceProfile',
-                    NAMESPACE => { Profile => 'http://ns.google.com/photos/dd/1.0/profile/' },
-                    CameraIndices => { List => 'Seq', Writable => 'integer' },
-                    Type => { },
-                },
-            },
-        },
-    },
-    Cameras => {
-        List => 'Seq',
-        FlatName => '',
-        Struct => {
-            STRUCT_NAME => 'DeviceCameras',
-            NAMESPACE => { Device => 'http://ns.google.com/photos/dd/1.0/device/' },
-            Camera => {
-                Struct => {
-                    STRUCT_NAME => 'DeviceCamera',
-                    NAMESPACE => { Camera => 'http://ns.google.com/photos/dd/1.0/camera/' },
-                    DepthMap => {
-                        Struct => {
-                            STRUCT_NAME => 'DeviceDepthMap',
-                            NAMESPACE => { DepthMap => 'http://ns.google.com/photos/dd/1.0/depthmap/' },
-                            ConfidenceURI => { },
-                            DepthURI    => { },
-                            Far         => { Writable => 'real' },
-                            Format      => { },
-                            ItemSemantic=> { },
-                            MeasureType => { },
-                            Near        => { Writable => 'real' },
-                            Units       => { },
-                            Software    => { },
-                            FocalTableEntryCount => { Writable => 'integer' },
-                            FocalTable  => { }, # (base64)
-                        },
-                    },
-                    Image => {
-                        Struct => {
-                            STRUCT_NAME => 'DeviceImage',
-                            NAMESPACE => { Image => 'http://ns.google.com/photos/dd/1.0/image/' },
-                            ItemSemantic=> { },
-                            ItemURI     => { },
-                        },
-                    },
-                    ImagingModel => {
-                        Struct => {
-                            STRUCT_NAME => 'DeviceImagingModel',
-                            NAMESPACE => { ImagingModel => 'http://ns.google.com/photos/dd/1.0/imagingmodel/' },
-                            Distortion      => { }, # (base64)
-                            DistortionCount => { Writable => 'integer' },
-                            FocalLengthX    => { Writable => 'real' },
-                            FocalLengthY    => { Writable => 'real' },
-                            ImageHeight     => { Writable => 'integer' },
-                            ImageWidth      => { Writable => 'integer' },
-                            PixelAspectRatio=> { Writable => 'real' },
-                            PrincipalPointX => { Writable => 'real' },
-                            PrincipalPointY => { Writable => 'real' },
-                            Skew            => { Writable => 'real' },
-                        },
-                    },
-                    PointCloud => {
-                        Struct => {
-                            STRUCT_NAME => 'DevicePointCloud',
-                            NAMESPACE => { PointCloud => 'http://ns.google.com/photos/dd/1.0/pointcloud/' },
-                            PointCloud  => { Writable => 'integer' },
-                            Points      => { },
-                            Metric      => { Writable => 'boolean' },
-                        },
-                    },
-                    Pose => { Struct => \%sPose },
-                    LightEstimate => {
-                        Struct => {
-                            STRUCT_NAME => 'DeviceLightEstimate',
-                            NAMESPACE => { LightEstimate => 'http://ns.google.com/photos/dd/1.0/lightestimate/' },
-                            ColorCorrectionR => { Writable => 'real' },
-                            ColorCorrectionG => { Writable => 'real' },
-                            ColorCorrectionB => { Writable => 'real' },
-                            PixelIntensity   => { Writable => 'real' },
-                        },
-                    },
-                    VendorInfo => { Struct => \%sVendorInfo },
-                    AppInfo    => { Struct => \%sAppInfo },
-                    Trait => { },
-                },
-            },
-        },
-    },
-    VendorInfo  => { Struct => \%sVendorInfo },
-    AppInfo     => { Struct => \%sAppInfo },
-    EarthPos    => { Struct => \%sEarthPose },
-    Pose        => { Struct => \%sPose },
-    Planes => {
-        List => 'Seq',
-        FlatName => '',
-        Struct => {
-            STRUCT_NAME => 'DevicePlanes',
-            NAMESPACE => { Device => 'http://ns.google.com/photos/dd/1.0/device/' },
-            Plane => {
-                Struct => {
-                    STRUCT_NAME => 'DevicePlane',
-                    NAMESPACE => { Plane => 'http://ns.google.com/photos/dd/1.0/plane/' },
-                    Pose    => { Struct => \%sPose },
-                    ExtentX => { Writable => 'real' },
-                    ExtentZ => { Writable => 'real' },
-                    BoundaryVertexCount => { Writable => 'integer' },
-                    Boundary => { },
-                },
-            },
-        },
-    },
-);
-
-# Google container tags (ref https://developer.android.com/guide/topics/media/platform/hdr-image-format)
-# NOTE: The namespace prefix used by ExifTool is 'GContainer' instead of 'Container'
-# dueo to a conflict with Google's depth-map Device 'Container' namespace!
-# (see ../pics/GooglePixel8Pro.jpg sample image)
-%Image::ExifTool::XMP::GContainer = (
-    %xmpTableDefaults,
-    GROUPS => { 1 => 'XMP-GContainer', 2 => 'Image' },
-    NAMESPACE => 'GContainer',
-    NOTES => q{
-        Google Container namespace.  ExifTool uses the prefix 'GContainer' instead
-        of 'Container' to avoid a conflict with the Google Device Container
-        namespace.
-    },
-    Directory => {
-        Name => 'ContainerDirectory',
-        FlatName => 'Directory',
-        List => 'Seq',
-        Struct => {
-            STRUCT_NAME => 'Directory',
-            Item => {
-                Namespace => 'GContainer',
-                Struct => {
-                    STRUCT_NAME => 'Item',
-                    # (use 'GItem' to avoid conflict with Google Device Container Item)
-                    NAMESPACE => { GItem => 'http://ns.google.com/photos/1.0/container/item/'},
-                    Mime    => { RawConv => '$$self{ProcessGoogleTrailer} = $val' },
-                    Semantic => { },
-                    Length   => { Writable => 'integer' },
-                    Label    => { },
-                    Padding  => { Writable => 'integer' },
-                    URI      => { },
-                },
-            },
-        },
-    },
-);
-
 # Getty Images namespace (ref PH)
 %Image::ExifTool::XMP::GettyImages = (
     %xmpTableDefaults,
@@ -2415,7 +1940,6 @@ sub Init_crd($)
     }
 }
 
-
 1;  #end
 
 __END__
